@@ -71,6 +71,8 @@
 #'   data for validation, and \code{skip}, which skips the validation step.
 #' @param verbose Optional, If \code{TRUE}, supply debug outputs in Platform
 #'   logs and make prediction child jobs visible.
+#' @param civisml_version Optional, a one-length character vector of the
+#'   CivisML version. The default is "prod", the latest version in production
 #' @param dvs_to_predict Optional, For scoring, this should be a vector of column
 #'   names of dependent variables to include in the output table. It must be a
 #'   subset of the \code{dependent_variable} vector provided for training.
@@ -290,7 +292,8 @@ civis_ml <- function(x,
                      polling_interval = NULL,
                      validation_data = c('train', 'skip'),
                      n_jobs = NULL,
-                     verbose = FALSE) {
+                     verbose = FALSE,
+                     civisml_version = "prod") {
 
   UseMethod("civis_ml", x)
 }
@@ -316,7 +319,8 @@ civis_ml.data.frame <- function(x,
                                 polling_interval = NULL,
                                 validation_data = c('train', 'skip'),
                                 n_jobs = NULL,
-                                verbose = FALSE) {
+                                verbose = FALSE,
+                                civisml_version = "prod") {
 
   oos_scores_if_exists <- match.arg(oos_scores_if_exists)
   validation_data <- match.arg(validation_data)
@@ -326,7 +330,8 @@ civis_ml.data.frame <- function(x,
     oos_scores_db_id <- get_database_id(oos_scores_db)
   }
 
-  file_id <- stash_local_dataframe(x)
+  tmpl_id <- get_train_template_id(civisml_version = civisml_version)
+  file_id <- stash_local_dataframe(x, tmpl_id)
   create_and_run_model(file_id = file_id,
                        dependent_variable = dependent_variable,
                        excluded_columns = excluded_columns,
@@ -346,7 +351,8 @@ civis_ml.data.frame <- function(x,
                        validation_data = validation_data,
                        n_jobs = n_jobs,
                        notifications = notifications,
-                       verbose = verbose)
+                       verbose = verbose,
+                       civisml_version = civisml_version)
 }
 
 #' @export
@@ -370,7 +376,8 @@ civis_ml.civis_table <- function(x,
                                  polling_interval = NULL,
                                  validation_data = c('train', 'skip'),
                                  n_jobs = NULL,
-                                 verbose = FALSE) {
+                                 verbose = FALSE,
+                                 civisml_version = "prod") {
 
   oos_scores_if_exists <- match.arg(oos_scores_if_exists)
   validation_data <- match.arg(validation_data)
@@ -402,7 +409,8 @@ civis_ml.civis_table <- function(x,
                        validation_data = validation_data,
                        n_jobs = n_jobs,
                        notifications = notifications,
-                       verbose = verbose)
+                       verbose = verbose,
+                       civisml_version = civisml_version)
 }
 
 #' @export
@@ -426,7 +434,8 @@ civis_ml.civis_file <- function(x,
                                 polling_interval = NULL,
                                 validation_data = c('train', 'skip'),
                                 n_jobs = NULL,
-                                verbose = FALSE) {
+                                verbose = FALSE,
+                                civisml_version = "prod") {
 
   oos_scores_if_exists <- match.arg(oos_scores_if_exists)
   validation_data <- match.arg(validation_data)
@@ -455,7 +464,8 @@ civis_ml.civis_file <- function(x,
                        validation_data = validation_data,
                        n_jobs = n_jobs,
                        notifications = notifications,
-                       verbose = verbose)
+                       verbose = verbose,
+                       civisml_version = civisml_version)
 }
 
 #' @export
@@ -479,7 +489,8 @@ civis_ml.character <- function(x,
                                polling_interval = NULL,
                                validation_data = c('train', 'skip'),
                                n_jobs = NULL,
-                               verbose = FALSE) {
+                               verbose = FALSE,
+                               civisml_version = "prod") {
 
   oos_scores_if_exists <- match.arg(oos_scores_if_exists)
   validation_data <- match.arg(validation_data)
@@ -509,17 +520,18 @@ civis_ml.character <- function(x,
                        validation_data = validation_data,
                        n_jobs = n_jobs,
                        notifications = notifications,
-                       verbose = verbose)
+                       verbose = verbose,
+                       civisml_version = civisml_version)
 }
 
 #' Stash a data frame in feather or csv format, depending on CivisML version.
 #'
 #' @param x data.frame to stash
+#' @param tmpl_id CivisML training template id
 #'
 #' @return file id where dataframe is stored
-stash_local_dataframe <- function(x) {
+stash_local_dataframe <- function(x, tmpl_id) {
   # Try to stash a dataframe in feather format.
-  tmpl_id <- getOption("civis.ml_train_template_id")
   tmp_path <- tempfile()
 
   if (tmpl_id > 9969) {
@@ -561,7 +573,8 @@ create_and_run_model <- function(file_id = NULL,
                                  validation_data = NULL,
                                  n_jobs = NULL,
                                  notifications = NULL,
-                                 verbose = FALSE) {
+                                 verbose = FALSE,
+                                 civisml_version = "prod") {
 
   args <- list(
     MODEL = model_type,
@@ -663,7 +676,7 @@ create_and_run_model <- function(file_id = NULL,
     job_name <- paste0(model_name, " Train")
   }
 
-  tmpl_id <- getOption("civis.ml_train_template_id")
+  tmpl_id <- get_train_template_id(civisml_version = civisml_version)
   run <- run_model(template_id = tmpl_id, name = job_name, arguments = args,
                    notifications = notifications,
                    polling_interval = polling_interval,
